#
# spec file for package python-Glymur
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dotted_version 0.12.9.post1
Name:           python-Glymur
Version:        0.12.9post1
Release:        1.2
Summary:        Tools for accessing JPEG2000 files
License:        MIT
URL:            https://github.com/quintusdias/glymur
Source:         https://github.com/quintusdias/glymur/archive/v%{version}.tar.gz#/Glymur-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  procps
BuildRequires:  python-rpm-macros
Requires:       python-lxml
Requires:       python-numpy
Requires:       python-packaging
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scikit-image}
# /SECTION
%python_subpackages

%description
Python interface to the OpenJPEG library

%prep
%autosetup -p1 -n glymur-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/jp2dump
%python_clone -a %{buildroot}%{_bindir}/tiff2jp2
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test says: "SCENARIO:  the XDG_CONFIG_HOME environment variable is not present"
# which is not true with our pytest macro
donttest+="test_config_dir_on_windows"
%pytest -k "not ($donttest)"

%post
%python_install_alternative jp2dump tiff2jp2

%postun
%python_uninstall_alternative jp2dump

%files %{python_files}
%doc README.md CHANGES.txt
%license LICENSE.txt
%python_alternative %{_bindir}/jp2dump
%python_alternative %{_bindir}/tiff2jp2
%{python_sitelib}/glymur
%{python_sitelib}/Glymur-%{dotted_version}.dist-info

%changelog
* Fri Jan 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.12.9post1:
  * Fix setup.cfg for v0.12.9 release
  * Fix handling of null-bytes with XML data
  * Add API references to docs
  * Qualify on python 3.12
  * Fix printing issue on 3.12beta, Fedora rawhide
  * Fix failing test on fedora
  * Change private attribute to prevent downstream test failure with tiatoolbox
  * Fix conversion of uint16 TIFFs to single jp2 tile.
  * Fix command line arguments --psnr and --cratio.
  * Minor documentation updates.
  * Add --num-threads option to tiff2jp2.
  * Refactor GeoJP2 code to get support for GML-JP2.
  * Fix broken uint16 test.
  * Fix stripped tiff oddity with partial last strip.
  * Refactor RGBA interface.
  * Fix plane ordering on RGBA TIFFs on big-endian
  * Fix TIFF reads on partian final strips
  * Fix regression on default value of numres.
  * Add support for type hints.
  * Remove support for Python 3.8.
  * Fix error condition when MCT specified as false for grayscale image.
  * Make properties conform to numpydoc.
  * Fix YCbCr/JPEG TIFF conversion test failure on Fedora.
  * Stop using libtiff to create test files on the fly.
  * Do not error out for JP2 files with multiple codestreams.
  * Relax validation for invalid JP2 files with multiple jp2h boxes.
  * Drop support for python 3.7.
  * Add support for ICC profiles, colormaps when converting from TIFF.
  * Add shortcut for retrieving lowest resolution thumbnail.
  * Remove setuptools from runtime requirement.
  * Improve pretty-printing of Exif UUIDs, TLM segments.
  * Change default value of --create-xmp-uuid to True.
  * Error out early when writing 1x1 tile-by-tile
  * Do not install test, test.data packages
  * Fix reads where COD segment not at index[2]
  * Fix ResolutionBox with tiff2jp2
- Drop patch glymur-pr553-no-setuptools.patch, included upstream.
* Thu Sep 22 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.11.7
  * Error out early when writing 1x1 tile-by-tile
- Update to v0.11.6
  * Do not install test, test.data packages
  * Fix Changelog regarding v0.11.6
  * Fix reads where COD segment not at index[2]
  * This fix not included in 0.11.5
- Update to v0.11.5
  * Fix reads where COD segment not at index[2]
- Update to v0.11.4
  * Fix ResolutionBox with tiff2jp2
- Update to v0.11.3
  * Fix placement of Resolutionbox
- Update to v0.11.2
  * Relax ResolutionBox requirement on child boxes.
- Update to v0.11.1
  * Improve efficiency of striped TIFF to tiled JP2 conversion.
- Update to v0.11.0
  * Add options for supporting ResolutionBoxes.
  * Fix ctypes interface to C library on windows.
  * Add option to convert XMLPacket into UUID box.
  * Add option for excluding tags from Exif UUID box.
* Tue Aug 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.10.2
    Fix appveyor builds
    Fix tiff2jp2 when ExifTag is present
    Address warnings in TIFF interface
    Update glymur.config documentation
* Thu Jul  7 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.10.1
  * Add write capability for Resolution boxes
  * Add example documentation for reading layers
- Release v0.10.0
  * Allow parsing of Exif UUIDs missing the EXIF\00\00 lead-in
  * Add read support for additional Exif tags
  * Add support for TLM segment generation
- Release  v0.9.9
  * Fix bug retrieving some TIFF tags on big endian systems
- Release v0.9.7
  * Remove distutils in favor of setuptools
  * Add recognition of IMF profiles
  * Add ndim, dtype properties
- Release v0.9.5
  * Add support for generation of PLT markers
  * Add support for converting TIFFs to JPEG 2000
- Release v0.9.4
  * Add support for writing images tile-by-tile
  * Add support for opj_set_decoded_components
  * Remove support for Python 3.6
- Add glymur-pr553-no-setuptools.patch
  * gh#quintusdias/glymur#553 + gh#quintusdias/glymur#554
* Thu Feb 11 2021 Benjamin Greiner <code@bnavigator.de>
- NEP 29: NumPy dropped Python 3.6 -- skip python36 build in TW
- Make importlib_resources conditional for Python < 3.7 (SLE/Leap)
* Sat Jan 23 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 0.9.3
  * Qualify on Python 3.9
  * Qualify on OpenJPEG 2.4.0
  * Add support for multithreaded writes.
- Always require importlib_resources for tests: the new python36
  flavor on TW needs it, the python38 flavor is okay with it being
  installed.
* Tue Jul 14 2020 Matej Cepl <mcepl@suse.com>
- Don't install tests
* Thu Jul  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.9.2
  * Update setup.py to include tests in source distribution to PyPi
  * Update gdal imports to comply with GDAL recommendations.
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.9.1
  * Removed support for python2.7
  * Fixed Cygwin support.
  * Fixed appveyor builds, Travis-CI framework reworked.
  * Some fragile tests removed.
  * Remove GDAL from setup.py requirements
* Mon Jan 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.8.19
  * Qualify on Python 3.8.
* Fri Dec  6 2019 Todd R <toddrme2178@gmail.com>
- Disable python2 support since dependencies dropped python2
- Use pytest to simplify test invocation
* Fri Sep 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by sunpy
